@@ -23,10 +23,10 @@ copyright = '2020, The Firebird Project'
 author = 'Pavel Císař'
 
 # The short X.Y version
-version = '0.8.0'
+version = '1.2.0'
 
 # The full version, including alpha/beta/rc tags
-release = '0.8.0'
+release = '1.2.0'
 
 
 # -- General configuration ---------------------------------------------------
@@ -37,7 +37,7 @@ release = '0.8.0'
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
-    'sphinxcontrib.napoleon',
+    'sphinx.ext.napoleon',
     'sphinx_autodoc_typehints',
     'sphinx.ext.todo',
 ]
@@ -78,7 +78,7 @@ html_theme_path = sphinx_bootstrap_theme.get_html_theme_path()
 # theme further.
 html_theme_options = {
     # Navigation bar title. (Default: ``project`` value)
-    #'navbar_title': "FDB",
+    #'navbar_title': "Firebird-driver",
 
     # Tab name for entire site. (Default: "Site")
     'navbar_site_name': "Content",
@@ -179,7 +179,9 @@ napoleon_include_special_with_doc = True
 napoleon_use_admonition_for_examples = False
 napoleon_use_admonition_for_notes = True
 napoleon_use_admonition_for_references = True
-napoleon_use_ivar = True
+napoleon_use_ivar = False
+napoleon_use_rtype = True
+napoleon_attr_annotations = True
 
 # -- Options for intersphinx extension ---------------------------------------
 
