@@ -45,9 +45,10 @@ from firebird.base.config import Config, StrOption, IntOption, BoolOption, EnumO
 from .types import NetProtocol
 
 class ServerConfig(Config):
-    """Server configuration."""
-    def __init__(self, name: str):
-        super().__init__(name)
+    """Server configuration.
+    """
+    def __init__(self, name: str, *, optional: bool=False, description: str=None):
+        super().__init__(name, optional=optional, description=description)
         #: Server host machine specification
         self.host: StrOption = \
             StrOption('host', "Server host machine specification")
@@ -59,7 +60,8 @@ class ServerConfig(Config):
             StrOption('user', "Defaul user name", default=os.environ.get('ISC_USER', None))
         #: Default user password, default is envar ISC_PASSWORD or None if not specified
         self.password: StrOption = \
-            StrOption('password', "Default user password", default=os.environ.get('ISC_PASSWORD', None))
+            StrOption('password', "Default user password",
+                      default=os.environ.get('ISC_PASSWORD', None))
         #: Configuration override
         self.config: StrOption = \
             StrOption('config', "Configuration override")
@@ -71,9 +73,10 @@ class ServerConfig(Config):
             BoolOption('trusted_auth', "Use trusted authentication", default=False)
 
 class DatabaseConfig(Config):
-    "Database configuration."
-    def __init__(self, name: str):
-        super().__init__(name)
+    """Database configuration.
+    """
+    def __init__(self, name: str, *, optional: bool=False, description: str=None):
+        super().__init__(name, optional=optional, description=description)
         #: Name of server where database is located
         self.server: StrOption = \
             StrOption('server', "Name of server where database is located")
@@ -85,7 +88,7 @@ class DatabaseConfig(Config):
             StrOption('database', "Database file specification or alias")
         #: Database filename should be passed in UTF8
         self.utf8filename: BoolOption = \
-            BoolOption('utf8filename', "Database filename should passed in UTF8")
+            BoolOption('utf8filename', "Database filename should be passed in UTF8")
         #: Protocol to be used for database
         self.protocol: EnumOption = \
             EnumOption('protocol', NetProtocol, "Protocol to be used for database")
@@ -94,7 +97,8 @@ class DatabaseConfig(Config):
             StrOption('user', "Defaul user name", default=os.environ.get('ISC_USER', None))
         #: Default user password, default is envar ISC_PASSWORD or None if not specified
         self.password: StrOption = \
-            StrOption('password', "Default user password", default=os.environ.get('ISC_PASSWORD', None))
+            StrOption('password', "Default user password",
+                      default=os.environ.get('ISC_PASSWORD', None))
         #: Use trusted authentication, default: False
         self.trusted_auth: BoolOption = \
             BoolOption('trusted_auth', "Use trusted authentication", default=False)
@@ -112,13 +116,14 @@ class DatabaseConfig(Config):
             IntOption('timeout', "Connection timeout")
         #: Do not use linger for database connection
         self.no_linger: BoolOption = \
-            BoolOption('no_linger', "Do not use linger for database connections")
+            BoolOption('no_linger', "Do not use linger for database connection")
         #: Page cache size override for database connection
         self.cache_size: IntOption = \
-            IntOption('cache_size', "Page cache size override for database connections")
+            IntOption('cache_size', "Page cache size override for database connection")
         #: Dummy packet interval for this database connection
         self.dummy_packet_interval: IntOption = \
-            IntOption('dummy_packet_interval', "Dummy packet interval for this database connections")
+            IntOption('dummy_packet_interval',
+                      "Dummy packet interval")
         #: Configuration override
         self.config: StrOption = \
             StrOption('config', "Configuration override")
@@ -128,32 +133,32 @@ class DatabaseConfig(Config):
         # Create options
         #: Database create option. Page size to be used.
         self.page_size: IntOption = \
-            IntOption('page_size', "Page size to be used")
+            IntOption('page_size', "Page size to be used for created database.")
         #: Database create option. Write mode (True = sync/False = async).
         self.forced_writes: BoolOption = \
-            BoolOption('forced_writes', "Write mode (True = sync/False = async)")
+            BoolOption('forced_writes', "Write mode for created database (True = sync, False = async)")
         #: Database create option. Character set for the database.
         self.db_charset: StrOption = \
-            StrOption('db_charset', "Character set for the database")
+            StrOption('db_charset', "Character set for created database")
         #: Database create option. SQL dialect for the database.
         self.db_sql_dialect: IntOption = \
-            IntOption('db_sql_dialect', "SQL dialect for the database")
+            IntOption('db_sql_dialect', "SQL dialect for created database")
         #: Database create option. Page cache size override for database.
         self.db_cache_size: IntOption = \
-            IntOption('db_cache_size', "Page cache size override for database")
+            IntOption('db_cache_size', "Page cache size override for created database")
         #: Database create option. Sweep interval for the database.
         self.sweep_interval: IntOption = \
-            IntOption('sweep_interval', "Sweep interval for the database")
+            IntOption('sweep_interval', "Sweep interval for created database")
         #: Database create option. Data page space usage (True = reserve space, False = Use all space).
         self.reserve_space: BoolOption = \
             BoolOption('reserve_space',
-                       "Data page space usage (True = reserve space, False = Use all space)")
+                       "Data page space usage for created database (True = reserve space, False = Use all space)")
 
 class DriverConfig(Config):
-    "Driver configuration."
+    """Firebird driver configuration.
+    """
     def __init__(self, name: str):
         super().__init__(name)
-        self._parser: ConfigParser = ConfigParser(interpolation=ExtendedInterpolation())
         #: Path to Firebird client library
         self.fb_client_library: StrOption = \
             StrOption('fb_client_library', "Path to Firebird client library")
@@ -163,9 +168,13 @@ class DriverConfig(Config):
                       "BLOB size threshold. Bigger BLOB will be returned as stream BLOBs.",
                       default=65536)
         #: Default database configuration ('firebird.db.defaults')
-        self.db_defaults: DatabaseConfig = DatabaseConfig('firebird.db.defaults')
+        self.db_defaults: DatabaseConfig = DatabaseConfig('firebird.db.defaults',
+                                                          optional=True,
+                                                          description="Default database configuration.")
         #: Default server configuration ('firebird.server.defaults')
-        self.server_defaults: ServerConfig = ServerConfig('firebird.server.defaults')
+        self.server_defaults: ServerConfig = ServerConfig('firebird.server.defaults',
+                                                          optional=True,
+                                                          description="Default server configuration.")
         #: Registered servers
         self.servers: ConfigListOption = \
             ConfigListOption('servers', "Registered servers", ServerConfig)
@@ -184,22 +193,24 @@ class DriverConfig(Config):
 
         Return list of successfully read files.
         """
-        read_ok = self._parser.read(filenames, encoding)
-        self._parser.clear()
-        self.load_config(self._parser)
+        parser = ConfigParser(interpolation=ExtendedInterpolation())
+        read_ok = parser.read(filenames, encoding)
+        self.load_config(parser)
         return read_ok
     def read_file(self, f):
         """Read configuration from a file-like object.
 
         The `f` argument must be iterable, returning one line at a time.
         """
-        self._parser.clear()
-        self._parser.read_file(f)
+        parser = ConfigParser(interpolation=ExtendedInterpolation())
+        parser.read_file(f)
+        self.load_config(parser)
     def read_string(self, string: str) -> None:
-        "Read configuration from a given string."
-        self._parser.clear()
-        self._parser.read_string(string)
-        self.load_config(self._parser)
+        """Read configuration from a given string.
+        """
+        parser = ConfigParser(interpolation=ExtendedInterpolation())
+        parser.read_string(string)
+        self.load_config(parser)
     def read_dict(self, dictionary: Dict) -> None:
         """Read configuration from a dictionary.
 
@@ -210,17 +221,19 @@ class DriverConfig(Config):
         All types held in the dictionary are converted to strings during
         reading, including section names, option names and keys.
         """
-        self._parser.clear()
-        self._parser.read_dict(dictionary)
-        self.load_config(self._parser)
+        parser = ConfigParser(interpolation=ExtendedInterpolation())
+        parser.read_dict(dictionary)
+        self.load_config(parser)
     def get_server(self, name: str) -> ServerConfig:
-        "Return server configuration."
+        """Returns server configuration.
+        """
         for srv in self.servers.value:
             if srv.name == name:
                 return srv
         return None
     def get_database(self, name: str) -> DatabaseConfig:
-        "Return database configuration."
+        """Returns database configuration.
+        """
         for db in self.databases.value:
             if db.name == name:
                 return db
@@ -228,46 +241,46 @@ class DriverConfig(Config):
     def register_server(self, name: str, config: str=None) -> ServerConfig:
         """Register server.
 
-Arguments:
-    name: Server name.
-    config: Optional server configuration string in ConfigParser format in [name] section.
+        Arguments:
+            name: Server name.
+            config: Optional server configuration string in ConfigParser format in [name] section.
 
-Returns:
-   ServerConfig: For newly registered server
+        Returns:
+           ServerConfig: For newly registered server
 
-Raises:
-    ValueError: If server is already registered.
-"""
+        Raises:
+            ValueError: If server is already registered.
+        """
         if self.get_server(name) is not None:
             raise ValueError(f"Server '{name}' already registered.")
         srv_config = ServerConfig(name)
         self.servers.value.append(srv_config)
         if config:
-            self._parser.clear()
-            self._parser.read_string(config)
-            srv_config.load_config(self._parser, name)
+            parser = ConfigParser(interpolation=ExtendedInterpolation())
+            parser.read_string(config)
+            srv_config.load_config(parser, name)
         return srv_config
     def register_database(self, name: str, config: str=None) -> DatabaseConfig:
         """Register database.
 
-Arguments:
-    name: Database name.
-    config: Optional database configuration string in ConfigParser format in [name] section.
+        Arguments:
+            name: Database name.
+            config: Optional database configuration string in ConfigParser format in [name] section.
 
-Returns:
-   DatabaseConfig: For newly registered database
+        Returns:
+           DatabaseConfig: For newly registered database
 
-Raises:
-    ValueError: If database is already registered.
-"""
+        Raises:
+            ValueError: If database is already registered.
+        """
         if self.get_database(name) is not None:
             raise ValueError(f"Database '{name}' already registered.")
         db_config = DatabaseConfig(name)
         self.databases.value.append(db_config)
         if config:
-            self._parser.clear()
-            self._parser.read_string(config)
-            db_config.load_config(self._parser, name)
+            parser = ConfigParser(interpolation=ExtendedInterpolation())
+            parser.read_string(config)
+            db_config.load_config(parser, name)
         return db_config
 
 # Configuration
